[![](https://img.shields.io/pypi/v/foliantcontrib.utils.svg)](https://pypi.org/project/foliantcontrib.utils/) [![](https://img.shields.io/github/v/tag/foliant-docs/foliantcontrib.utils.svg?label=GitHub)](https://github.com/foliant-docs/foliantcontrib.utils)

# Foliant utils

This package contains various utils for Foliant extensions creators.

## Installation

```bash
pip3 install foliantcontrib.utils
```

# Contents

* [Generic utils](docs/utils.md) — generic little tools to use in Foliant extensions.
* [PreprocessorExt](docs/preprocessor_ext.md) — extended base class for Preprocessors with boilerplate code and useful features.
* [Combined Options](docs/combined_options.md) — wrapper class which simplifies working with extension options.
* [Header Anchors](docs/header_anchors.md) — tools to generate anchors for headings in documents.
* [Chapters](docs/chapters.md) — tools to work with chapters in foliant.yml.
